@@ -65,7 +65,7 @@ char *minus_f = (char)NULL;
 char *minus_F = (char)NULL;
 char *gecos;
 char *prog = (char)NULL;
-char *root = "postmaster";
+char *root = NULL;
 char *tls_cert = "/etc/ssl/certs/ssmtp.pem";	/* Default Certificate */
 char *uad = (char)NULL;
 
@@ -640,8 +640,7 @@ rcpt_remap() -- Alias systems-level users to the person who
 char *rcpt_remap(char *str)
 {
 	struct passwd *pw;
-
-	if(strchr(str, '@') ||
+	if((root==NULL) || strlen(root)==0 || strchr(str, '@') ||
 		((pw = getpwnam(str)) == NULL) || (pw->pw_uid > MAXSYSUID)) {
 		return(append_domain(str));	/* It's not a local systems-level user */
 	}
@@ -937,6 +936,34 @@ bool_t read_config()
 				}
 			}
 #endif
+			/* Command-line overrides these */
+			else if(strcasecmp(p, "AuthUser") == 0 && !auth_user) {
+				if((auth_user = strdup(q)) == (char *)NULL) {
+					die("parse_config() -- strdup() failed");
+				}
+
+				if(log_level > 0) {
+					log_event(LOG_INFO, "Set AuthUser=\"%s\"\n", auth_user);
+				}
+			}
+			else if(strcasecmp(p, "AuthPass") == 0 && !auth_pass) {
+				if((auth_pass = strdup(q)) == (char *)NULL) {
+					die("parse_config() -- strdup() failed");
+				}
+
+				if(log_level > 0) {
+					log_event(LOG_INFO, "Set AuthPass=\"%s\"\n", auth_pass);
+				}
+			}
+			else if(strcasecmp(p, "AuthMethod") == 0 && !auth_method) {
+				if((auth_method = strdup(q)) == (char *)NULL) {
+					die("parse_config() -- strdup() failed");
+				}
+
+				if(log_level > 0) {
+					log_event(LOG_INFO, "Set AuthMethod=\"%s\"\n", auth_method);
+				}
+			}
 			else {
 				log_event(LOG_INFO, "Unable to set %s=\"%s\"\n", p, q);
 			}
@@ -1326,7 +1353,7 @@ int ssmtp(char *argv[])
 			auth_pass = strdup("");
 		}
 
-		if(strcasecmp(auth_method, "cram-md5")) {
+		if(strcasecmp(auth_method, "cram-md5") == 0) {
 			smtp_write(sock, "AUTH CRAM-MD5");
 			(void)alarm((unsigned) MEDWAIT);
 
